==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/cave/dialogs_es.lua <==

dialogId("jes-m-netopyr", "font_small", "That bat must be terribly strong.")
dialogStr("Ese murciélago debe ser terriblemente fuerte.")


dialogId("jes-v-tojo", "font_big", "Well, yes.")
dialogStr("Oh si.")


dialogId("jes-m-tvor", "font_small", "That red creature is a little bit strange.")
dialogStr("Esa criatura roja es un poquito extraña.")


dialogId("jes-v-nestezuj", "font_big", "That may be true, but I think we are going to need it.")
dialogStr("Puede ser verdad, pero pienso que lo vamos a necesitar.")


dialogId("jes-v-uzke", "font_big", "It`s too narrow for me. You have to do it on your own down there.")
dialogStr("Es muy estrecho para mi. Vas a tener que vértelas por ti mismo ahí abajo.")


dialogId("jes-m-ryba", "font_small", "That white fish is a terrible obstacle.")
dialogStr("Ese pez blanco es un terrible obstáculo.")


dialogId("jes-v-kamen", "font_big", "Fish? I thought it was only a stone.")
dialogStr("¿Pez? Pensé que sólo era una piedra.")


dialogId("jes-v-gral", "font_big", "I think that we should be looking for the Grail somewhere else...")
dialogStr("Creo que deberíamos estar buscando el Grial en otro lugar...")


dialogId("jes-m-deprese", "font_small", "Don`t be depressive. We will solve this in no time.")
dialogStr("No te deprimas. Arreglaremos esto rápidamente.")


dialogId("jes-v-nevim", "font_big", "I am not so sure.")
dialogStr("Yo no estoy tan seguro.")


dialogId("jes-m-takvidis", "font_small", "See? You are here.")
dialogStr("¿Ves? Tu estás aquí.")


dialogId("jes-m-potvora0", "font_small", "What kind of color-shifting monster is this?")
dialogStr("¿Que clase de monstruo que cambia de color es éste?")


dialogId("jes-m-potvora1", "font_small", "This is an abomination.")
dialogStr("Esta es una abominación.")


dialogId("jes-m-potvora2", "font_small", "This is an offense of Nature.")
dialogStr("Esto es una ofensa a la Naturaleza.")


dialogId("jes-v-potvora0", "font_big", "It is called the Flashy hammerhead.")
dialogStr("Es llamado el Luminoso cabeza de martillo.")


dialogId("jes-v-potvora1", "font_big", "It is called the Glossy repulsor.")
dialogStr("Ese es llamado el Brillante repulsor .")


dialogId("jes-v-potvora2", "font_big", "It is called the Politician fish.")
dialogStr("Ese es llamado el pez Político.")


dialogId("jes-m-netopyr0", "font_small", "This bat is kind of strange.")
dialogStr("Este murciélago es un poco extraño.")


dialogId("jes-v-netopyr0", "font_big", "This is very phlegmatic bat.")
dialogStr("Este es un murciélago muy flemático.")


dialogId("jes-m-netopyr1", "font_small", "This is a stuffed bat.")
dialogStr("Este es un murciélago relleno.")


dialogId("jes-v-netopyr1", "font_big", "It`s a sculpture of bat.")
dialogStr("Es una escultura de murciélago.")


dialogId("jes-m-netopyr2", "font_small", "It`s a stalagmite shaped as a bat.")
dialogStr("Es una estalagmita con forma de murciélago.")


dialogId("jes-v-netopyr2", "font_big", "It`s a plain stalagmite.")
dialogStr("Es una simple estalagmita.")


dialogId("jes-m-netopyr3", "font_small", "It`s just an ordinary piece of rock.")
dialogStr("Es sólamente un pedazo de roca ordinaria.")


dialogId("jes-v-nechut0", "font_big", "I think you are going to need that 'monster`.")
dialogStr("Creo que vas a necesitar ese \"Monstruo\".")


dialogId("jes-v-nechut1", "font_big", "I think you will have to overcome your dislike of that 'abomination`.")
dialogStr("Pienso que tendrás que sobreponerte a tu desagrado de esa \"abominación\".")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/cave/dialogs_es.lua <==

dialogId("jes-m-netopyr", "font_small", "That bat must be terribly strong.")
dialogStr("Ese murciélago debe ser terriblemente fuerte.")


dialogId("jes-v-tojo", "font_big", "Well, yes.")
dialogStr("Oh si.")


dialogId("jes-m-tvor", "font_small", "That red creature is a little bit strange.")
dialogStr("Esa criatura roja es un poquito extraña.")


dialogId("jes-v-nestezuj", "font_big", "That may be true, but I think we are going to need it.")
dialogStr("Puede ser verdad, pero pienso que lo vamos a necesitar.")


dialogId("jes-v-uzke", "font_big", "It’s too narrow for me. You have to do it on your own down there.")
dialogStr("Es muy estrecho para mi. Vas a tener que vértelas por ti mismo ahí abajo.")


dialogId("jes-m-ryba", "font_small", "That white fish is a terrible obstacle.")
dialogStr("Ese pez blanco es un terrible obstáculo.")


dialogId("jes-v-kamen", "font_big", "Fish? I thought it was only a stone.")
dialogStr("¿Pez? Pensé que sólo era una piedra.")


dialogId("jes-v-gral", "font_big", "I think that we should be looking for the Grail somewhere else...")
dialogStr("Creo que deberíamos estar buscando el Grial en otro lugar...")


dialogId("jes-m-deprese", "font_small", "Don’t be depressive. We will solve this in no time.")
dialogStr("No te deprimas. Arreglaremos esto rápidamente.")


dialogId("jes-v-nevim", "font_big", "I am not so sure.")
dialogStr("Yo no estoy tan seguro.")


dialogId("jes-m-takvidis", "font_small", "See? You are here.")
dialogStr("¿Ves? Tu estás aquí.")


dialogId("jes-m-potvora0", "font_small", "What kind of color-shifting monster is this?")
dialogStr("¿Que clase de monstruo que cambia de color es éste?")


dialogId("jes-m-potvora1", "font_small", "This is an abomination.")
dialogStr("Esta es una abominación.")


dialogId("jes-m-potvora2", "font_small", "This is an offense of Nature.")
dialogStr("Esto es una ofensa a la Naturaleza.")


dialogId("jes-v-potvora0", "font_big", "It is called the Flashy hammerhead.")
dialogStr("Es llamado el Luminoso cabeza de martillo.")


dialogId("jes-v-potvora1", "font_big", "It is called the Glossy repulsor.")
dialogStr("Ese es llamado el Brillante repulsor .")


dialogId("jes-v-potvora2", "font_big", "It is called the Politician fish.")
dialogStr("Ese es llamado el pez Político.")


dialogId("jes-m-netopyr0", "font_small", "This bat is kind of strange.")
dialogStr("Este murciélago es un poco extraño.")


dialogId("jes-v-netopyr0", "font_big", "This is very phlegmatic bat.")
dialogStr("Este es un murciélago muy flemático.")


dialogId("jes-m-netopyr1", "font_small", "This is a stuffed bat.")
dialogStr("Este es un murciélago relleno.")


dialogId("jes-v-netopyr1", "font_big", "It’s a sculpture of bat.")
dialogStr("Es una escultura de murciélago.")


dialogId("jes-m-netopyr2", "font_small", "It’s a stalagmite shaped as a bat.")
dialogStr("Es una estalagmita con forma de murciélago.")


dialogId("jes-v-netopyr2", "font_big", "It’s a plain stalagmite.")
dialogStr("Es una simple estalagmita.")


dialogId("jes-m-netopyr3", "font_small", "It’s just an ordinary piece of rock.")
dialogStr("Es sólamente un pedazo de roca ordinaria.")


dialogId("jes-v-nechut0", "font_big", "I think you are going to need that 'monster’.")
dialogStr("Creo que vas a necesitar ese \"Monstruo\".")


dialogId("jes-v-nechut1", "font_big", "I think you will have to overcome your dislike of that 'abomination’.")
dialogStr("Pienso que tendrás que sobreponerte a tu desagrado de esa \"abominación\".")
